Clazz.declarePackage("J.bspt");
(function(){
var c$ = Clazz.decorateAsClass(function(){
this.bspt = null;
this.count = 0;
Clazz.instantialize(this, arguments);}, J.bspt, "Element", null);
})();
;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
